*****************
Sharing protocols
*****************

- Via git

    - To publish:
        
      - Put protocols in directory

      - Commit

      - Push to github

    - To install:

      - Clone repository

      - Specify path to repositoy in config file

- Via python

    - To publish

        - Create python package with directory of protocols

        - Make variable specifying path to that directory

        - Provide entry point

        - Push to PyPI

    - To install

        - pip install ...



